@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # ******************************************************************************
-#  $Id: gdal_sieve.py a89b9ca12edc2d5551a2ad4db8bb569d8ecba334 2021-11-24 13:51:55 +0100 Even Rouault $
+#  $Id$
 #
 #  Project:  GDAL Python Interface
 #  Purpose:  Application for applying sieve filter to raster data.
@@ -40,12 +40,12 @@ from osgeo_utils.auxiliary.util import GetOutputDriverFor
 
 
 def Usage():
-    print("""gdal_sieve [-q] [-st threshold] [-4] [-8] [-o name=value]
+    print("""Usage: gdal_sieve [-q] [-st threshold] [-4] [-8] [-o name=value]
            srcfile [-nomask] [-mask filename] [-of format] [dstfile]""")
     return 1
 
 
-def main(argv):
+def main(argv=sys.argv):
     threshold = 2
     connectedness = 4
     quiet = False
